==> webkitgtk_2.4.10.orig.tar.xz: webkitgtk-2.4.10/Source/WebCore/fileapi/FileList.h <==
/*
 * Copyright (C) 2008 Apple Inc. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef FileList_h
#define FileList_h

#include "File.h"
#include "ScriptWrappable.h"
#include <wtf/PassRefPtr.h>
#include <wtf/RefCounted.h>
#include <wtf/RefPtr.h>
#include <wtf/Vector.h>

namespace WebCore {

class FileList : public ScriptWrappable, public RefCounted<FileList> {
public:
    static PassRefPtr<FileList> create()
    {
        return adoptRef(new FileList);
    }

    unsigned length() const { return m_files.size(); }
    File* item(unsigned index) const;

    bool isEmpty() const { return m_files.isEmpty(); }
    void clear() { m_files.clear(); }
    void append(PassRefPtr<File> file) { m_files.append(file); }
    Vector<String> paths() const;

private:
    FileList();

    Vector<RefPtr<File>> m_files;
};

} // namespace WebCore

#endif // FileList_h

==> webkitgtk-2.7.2.tar.xz: webkitgtk-2.7.2/Source/WebCore/fileapi/FileList.h <==
/*
 * Copyright (C) 2008 Apple Inc. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef FileList_h
#define FileList_h

#include "File.h"
#include "ScriptWrappable.h"
#include <wtf/PassRefPtr.h>
#include <wtf/RefCounted.h>
#include <wtf/RefPtr.h>
#include <wtf/Vector.h>

namespace WebCore {

class FileList : public ScriptWrappable, public RefCounted<FileList> {
public:
    static PassRefPtr<FileList> create()
    {
        return adoptRef(new FileList);
    }

    static PassRefPtr<FileList> create(Vector<RefPtr<File>>&& files)
    {
        return adoptRef(new FileList(WTF::move(files)));
    }

    unsigned length() const { return m_files.size(); }
    File* item(unsigned index) const;

    bool isEmpty() const { return m_files.isEmpty(); }
    Vector<String> paths() const;

private:
    FileList();
    FileList(Vector<RefPtr<File>>&& files) : m_files(files) { }

    // FileLists can only be changed by their owners.
    friend class DataTransfer;
    friend class FileInputType;
    void append(PassRefPtr<File> file) { m_files.append(file); }
    void clear() { m_files.clear(); }

    Vector<RefPtr<File>> m_files;
};

} // namespace WebCore

#endif // FileList_h
